@@ -11,7 +11,7 @@
 // This module provides general purpose utilities for the WavPack command-line
 // utilities and the self-extraction module.
 
-#if defined(WIN32)
+#if defined(_WIN32)
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <io.h>
@@ -31,13 +31,7 @@
 #include "wavpack.h"
 #include "utils.h"
 
-#ifdef WIN32
-#define fileno _fileno
-#define stat64 __stat64
-#define fstat64 _fstat64
-#endif
-
-#ifdef WIN32
+#ifdef _WIN32
 
 int copy_timestamp (const char *src_filename, const char *dst_filename)
 {
@@ -104,7 +98,7 @@ int copy_timestamp(const char *src_filename, const char *dst_filename)
 // then NULL is returned. Extensions with more than 3 letters don't count.  //
 //////////////////////////////////////////////////////////////////////////////
 
-#if defined(WIN32)
+#if defined(_WIN32)
 
 static int is_second_byte (char *filespec, char *pos);
 
@@ -165,7 +159,7 @@ char *filespec_ext (char *filespec)
 // returned.                                                                //
 //////////////////////////////////////////////////////////////////////////////
 
-#if (defined(__GNUC__) || defined(__sun)) && !defined(WIN32)
+#if (defined(__GNUC__) || defined(__sun)) && !defined(_WIN32)
 
 char *filespec_path (char *filespec)
 {
@@ -249,7 +243,7 @@ char *filespec_wild (char *filespec)
 // a pointer to the actual filename, or NULL if no filename can be found.   //
 //////////////////////////////////////////////////////////////////////////////
 
-#if defined(WIN32)
+#if defined(_WIN32)
 
 char *filespec_name (char *filespec)
 {
@@ -294,13 +288,13 @@ char *filespec_name (char *filespec)
 // shift-JIS.                                                               //
 //////////////////////////////////////////////////////////////////////////////
 
-#if defined(WIN32)
+#if defined(_WIN32)
 
 static int is_second_byte (char *filespec, char *pos)
 {
     unsigned char *cp = pos;
 
-    while (cp > filespec && ((cp [-1] >= 0x81 && cp [-1] <= 0x9f) ||
+    while (cp > (unsigned char *)filespec && ((cp [-1] >= 0x81 && cp [-1] <= 0x9f) ||
                              (cp [-1] >= 0xe0 && cp [-1] <= 0xfc)))
         cp--;
 
@@ -325,7 +319,7 @@ char yna (void)
     waiting_input = 1;
 
     while (1) {
-#if defined(WIN32)
+#if defined(_WIN32)
         key = _getch ();
 #else
         key = fgetc(stdin);
@@ -341,31 +335,39 @@ char yna (void)
         else if (key == '\r' || key == '\n') {
             if (choice) {
                 fprintf (stderr, "\r\n");
+                fflush (stderr);
                 break;
             }
-            else
+            else {
                 fprintf (stderr, "%c", 7);
+                fflush (stderr);
+            }
         }
         else if (key == 'Y' || key == 'y') {
-#ifdef WIN32
+#ifdef _WIN32
             fprintf (stderr, "%c\b", key);
+            fflush (stderr);
 #endif
             choice = 'y';
         }
         else if (key == 'N' || key == 'n') {
-#ifdef WIN32
+#ifdef _WIN32
             fprintf (stderr, "%c\b", key);
+            fflush (stderr);
 #endif
             choice = 'n';
         }
         else if (key == 'A' || key == 'a') {
-#ifdef WIN32
+#ifdef _WIN32
             fprintf (stderr, "%c\b", key);
+            fflush (stderr);
 #endif
             choice = 'a';
         }
-        else
+        else {
             fprintf (stderr, "%c", 7);
+            fflush (stderr);
+        }
     }
 
     waiting_input = 0;
@@ -382,7 +384,7 @@ char yna (void)
 
 extern int debug_logging_mode;
 
-#ifdef WIN32
+#ifdef _WIN32
 
 int get_app_path (char *app_path)
 {
@@ -524,7 +526,7 @@ void debug_line (char *error, ...)
 //////////////////////////////////////////////////////////////////////////////
 // Function to intercept ^C or ^Break typed at the console.                 //
 //////////////////////////////////////////////////////////////////////////////
-#if defined(WIN32)
+#if defined(_WIN32)
 static int break_flag;
 
 BOOL WINAPI ctrl_handler (DWORD ctrl)
@@ -589,6 +591,8 @@ void finish_line (void)
     }
     else
         fputc ('\n', stderr);
+
+    fflush (stderr);
 }
 #else
 //////////////////////////////////////////////////////////////////////////////
@@ -599,6 +603,7 @@ void finish_line (void)
 void finish_line (void)
 {
     fprintf (stderr, "        \n");
+    fflush (stderr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -678,7 +683,7 @@ int DoWriteFile (FILE *hFile, void *lpBuffer, uint32_t nNumberOfBytesToWrite, ui
     return !ferror (hFile);
 }
 
-#ifdef WIN32
+#ifdef _WIN32
 
 int64_t DoGetFileSize (FILE *hFile)
 {
@@ -746,7 +751,7 @@ int DoTruncateFile (FILE *hFile)
 {
     if (hFile) {
         fflush (hFile);
-#if defined(WIN32)
+#if defined(_WIN32)
         return !_chsize (_fileno (hFile), 0);
 #else
         return !ftruncate(fileno (hFile), 0);
@@ -766,7 +771,7 @@ int DoDeleteFile (char *filename)
 // displaying progress of batch operations with the console window minimized.  //
 /////////////////////////////////////////////////////////////////////////////////
 
-#ifdef WIN32
+#ifdef _WIN32
 
 void DoSetConsoleTitle (char *text)
 {
@@ -778,6 +783,7 @@ void DoSetConsoleTitle (char *text)
 void DoSetConsoleTitle (char *text)
 {
     fprintf (stderr, "\033]0;%s\007", text);
+    fflush (stderr);
 }
 
 #endif
