@@ -16,7 +16,7 @@
 
 // ReplayGain's [somewhat outdated] website: http://replaygain.org/
 
-#if defined(WIN32)
+#if defined(_WIN32)
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <io.h>
@@ -36,7 +36,7 @@
 #endif
 #endif
 
-#if defined(__GNUC__) && !defined(WIN32)
+#if defined(__GNUC__) && !defined(_WIN32)
 #include <sys/time.h>
 #else
 #include <sys/timeb.h>
@@ -51,18 +51,6 @@
 #include "wavpack.h"
 #include "utils.h"
 
-#ifdef DEBUG_ALLOC
-#define malloc malloc_db
-#define realloc realloc_db
-#define free free_db
-void *malloc_db (uint32_t size);
-void *realloc_db (void *ptr, uint32_t size);
-void free_db (void *ptr);
-int32_t dump_alloc (void);
-static char *strdup (const char *s)
- { char *d = malloc (strlen (s) + 1); return strcpy (d, s); }
-#endif
-
 ///////////////////////////// local variable storage //////////////////////////
 
 static const char *sign_on = "\n"
@@ -74,7 +62,7 @@ static const char *version_warning = "\n"
 
 static const char *usage =
 " Usage:   WVGAIN [-options] [@]infile[.wv] [...]\n"
-#if defined (WIN32) || defined (__OS2__)
+#if defined (_WIN32) || defined (__OS2__)
 "             (infiles may contain wildcards: ?,*)\n\n"
 #else
 "             (multiple input files are allowed)\n\n"
@@ -83,7 +71,7 @@ static const char *usage =
 "          -c  = clean ReplayGain values from all files (no analysis)\n"
 "          -d  = display calculated values only (no files are modified)\n"
 "          -i  = ignore .wvc file (forces hybrid lossy)\n"
-#if defined (WIN32) || defined (__OS2__)
+#if defined (_WIN32) || defined (__OS2__)
 "          -l  = run at low priority (for smoother multitasking)\n"
 #endif
 "          -n  = new files only (skip files with track info, or album\n"
@@ -91,7 +79,7 @@ static const char *usage =
 "          -q  = quiet (keep console output to a minimum)\n"
 "          -v  = write the version to stdout\n"
 "          -s  = show stored values only (no analysis)\n"
-#if defined (WIN32)
+#if defined (_WIN32)
 "          -z  = don't set console title to indicate progress\n\n"
 #else
 "          -z1 = set console title to indicate progress\n\n"
@@ -117,9 +105,9 @@ static int show_file_info (char *infilename, FILE *dst);
 static float calc_replaygain (uint32_t *histogram);
 static void display_progress (double file_progress);
 
-#define NO_ERROR 0L
-#define SOFT_ERROR 1
-#define HARD_ERROR 2
+#define WAVPACK_NO_ERROR    0
+#define WAVPACK_SOFT_ERROR  1
+#define WAVPACK_HARD_ERROR  2
 
 ///////////////////////////////////////////////////////////////////////////////////
 // The "main" function for the command-line WavPack ReplayGain Scanner/Processor //
@@ -132,9 +120,9 @@ int main (argc, argv) int argc; char **argv;
 #endif
     int  error_count = 0;
     char **matches = NULL;
-    int result = NO_ERROR;
+    int result = WAVPACK_NO_ERROR;
 
-#if defined(WIN32)
+#if defined(_WIN32)
     struct _finddata_t _finddata_t;
     char selfname [MAX_PATH];
 
@@ -161,14 +149,14 @@ int main (argc, argv) int argc; char **argv;
     }
 #endif
 
-#if defined (WIN32)
+#if defined (_WIN32)
    set_console_title = 1;      // on Windows, we default to messing with the console title
 #endif                          // on Linux, this is considered uncool to do by default
 
     // loop through command-line arguments
 
     while (--argc) {
-#if defined (WIN32)
+#if defined (_WIN32)
         if ((**++argv == '-' || **argv == '/') && (*argv)[1])
 #else
         if ((**++argv == '-') && (*argv)[1])
@@ -193,7 +181,7 @@ int main (argc, argv) int argc; char **argv;
                         display_mode = 1;
                         break;
 
-#if defined (WIN32)
+#if defined (_WIN32)
                     case 'L': case 'l':
                         SetPriorityClass (GetCurrentProcess(), IDLE_PRIORITY_CLASS);
                         break;
@@ -251,10 +239,14 @@ int main (argc, argv) int argc; char **argv;
         ++error_count;
     }
 
-    if (strcmp (WavpackGetLibraryVersionString (), PACKAGE_VERSION))
+    if (strcmp (WavpackGetLibraryVersionString (), PACKAGE_VERSION)) {
         fprintf (stderr, version_warning, WavpackGetLibraryVersionString (), PACKAGE_VERSION);
-    else if (!quiet_mode && !error_count)
+        fflush (stderr);
+    }
+    else if (!quiet_mode && !error_count) {
         fprintf (stderr, sign_on, VERSION_OS, WavpackGetLibraryVersionString ());
+        fflush (stderr);
+    }
 
     if (!num_files) {
         printf ("%s", usage);
@@ -317,7 +309,7 @@ int main (argc, argv) int argc; char **argv;
             fclose (list);
             free (infilename);
         }
-#if defined (WIN32)
+#if defined (_WIN32)
         else if (filespec_wild (infilename)) {
             FILE *list = fopen (infilename+1, "rt");
             intptr_t file;
@@ -370,8 +362,10 @@ int main (argc, argv) int argc; char **argv;
             if (check_break ())
                 break;
 
-            if (num_files > 1 && !quiet_mode)
+            if (num_files > 1 && !quiet_mode) {
                 fprintf (stderr, "\n%s:\n", matches [file_index]);
+                fflush (stderr);
+            }
 
             if (new_mode) {
                 WavpackContext *wpc;
@@ -386,7 +380,7 @@ int main (argc, argv) int argc; char **argv;
                     if (alreadyHasTag) {
                         if (album_mode) {
                             error_line ("ReplayGain album information already present...aborting");
-                            result = HARD_ERROR;
+                            result = WAVPACK_HARD_ERROR;
                             break;
                         }
                         else {
@@ -399,11 +393,11 @@ int main (argc, argv) int argc; char **argv;
 
             result = analyze_file (matches [file_index], track_histogram, &track_peak);
 
-            if (result != NO_ERROR) {
+            if (result != WAVPACK_NO_ERROR) {
                 ++error_count;
 
-                if (album_mode || result == HARD_ERROR) {
-                    result = HARD_ERROR;
+                if (album_mode || result == WAVPACK_HARD_ERROR) {
+                    result = WAVPACK_HARD_ERROR;
                     break;
                 }
                 else
@@ -428,16 +422,16 @@ int main (argc, argv) int argc; char **argv;
             else if (!display_mode) {
                 result = update_file (matches [file_index], track_gains [file_index], track_peaks [file_index], 0, 0);
 
-                if (result != NO_ERROR) {
+                if (result != WAVPACK_NO_ERROR) {
                     ++error_count;
 
-                    if (result == HARD_ERROR)
+                    if (result == WAVPACK_HARD_ERROR)
                         break;
                 }
             }
         }
 
-        if (result != HARD_ERROR) {
+        if (result != WAVPACK_HARD_ERROR) {
             album_gain = calc_replaygain (album_histogram);
 
             if (album_mode && !quiet_mode && num_files > 1) {
@@ -450,13 +444,15 @@ int main (argc, argv) int argc; char **argv;
         // If we are in album mode or clear mode, this is where we loop through and modify
         // the tags (or just show existing stored values).
 
-        if (result != HARD_ERROR)
+        if (result != WAVPACK_HARD_ERROR)
             for (file_index = 0; (clean_mode || album_mode || show_mode) && !display_mode && file_index < num_files; ++file_index) {
                 if (check_break ())
                     break;
 
-                if (num_files > 1 && !quiet_mode)
+                if (num_files > 1 && !quiet_mode) {
                     fprintf (stderr, "\n%s:\n", matches [file_index]);
+                    fflush (stderr);
+                }
 
                 if (show_mode)
                     result = show_file_info (matches [file_index], stdout);
@@ -465,19 +461,22 @@ int main (argc, argv) int argc; char **argv;
 
                 free (matches [file_index]);
 
-                if (result != NO_ERROR) {
+                if (result != WAVPACK_NO_ERROR) {
                     ++error_count;
 
-                    if (result == HARD_ERROR)
+                    if (result == WAVPACK_HARD_ERROR)
                         break;
                 }
             }
 
         if (num_files > 1) {
-            if (error_count)
+            if (error_count) {
                 fprintf (stderr, "\n **** warning: errors occurred in %d of %d files! ****\n", error_count, num_files);
+                fflush (stderr);
+            }
             else if (!quiet_mode) {
                 fprintf (stderr, "\n **** %d files successfully processed ****\n", num_files);
+                fflush (stderr);
             }
         }
 
@@ -488,10 +487,6 @@ int main (argc, argv) int argc; char **argv;
         error_line ("nothing to do!");
     }
 
-#ifdef DEBUG_ALLOC
-    error_line ("malloc_count = %d", dump_alloc ());
-#endif
-
     if (set_console_title)
         DoSetConsoleTitle ("WvGain Completed");
 
@@ -509,7 +504,7 @@ static void float_samples (float *dst, int32_t *src, uint32_t samcnt, float scal
 
 static int analyze_file (char *infilename, uint32_t *histogram, float *peak)
 {
-    int result = NO_ERROR, open_flags = 0, num_channels, wvc_mode;
+    int result = WAVPACK_NO_ERROR, open_flags = 0, num_channels, wvc_mode;
     uint32_t total_unpacked_samples = 0, window_samples;
     double progress = -1.0;
     int32_t *temp_buffer;
@@ -530,7 +525,7 @@ static int analyze_file (char *infilename, uint32_t *histogram, float *peak)
 
     if (!wpc) {
         error_line (error);
-        return SOFT_ERROR;
+        return WAVPACK_SOFT_ERROR;
     }
 
     wvc_mode = WavpackGetMode (wpc) & MODE_WVC;
@@ -538,20 +533,22 @@ static int analyze_file (char *infilename, uint32_t *histogram, float *peak)
 
     if (num_channels > 2) {
         error_line ("can't handle multichannel files yet!");
-        return SOFT_ERROR;
+        return WAVPACK_SOFT_ERROR;
     }
 
-    if (!quiet_mode)
+    if (!quiet_mode) {
         fprintf (stderr, "analyzing %s%s,", *infilename == '-' ? "stdin" :
             FN_FIT (infilename), wvc_mode ? " (+.wvc)" : "");
+        fflush (stderr);
+    }
 
     window_samples = WavpackGetSampleRate (wpc) / 20;
     temp_buffer = malloc (window_samples * 8);
 
     if (!filter_init (WavpackGetSampleRate (wpc)))
-        result = SOFT_ERROR;
+        result = WAVPACK_SOFT_ERROR;
 
-    while (result == NO_ERROR) {
+    while (result == WAVPACK_NO_ERROR) {
         uint32_t samples_to_unpack, samples_unpacked;
         int32_t level;
 
@@ -605,12 +602,13 @@ static int analyze_file (char *infilename, uint32_t *histogram, float *peak)
             break;
 
         if (check_break ()) {
-#if defined(WIN32)
+#if defined(_WIN32)
             fprintf (stderr, "^C\n");
 #else
             fprintf (stderr, "\n");
 #endif
-            result = HARD_ERROR;
+            fflush (stderr);
+            result = WAVPACK_HARD_ERROR;
             break;
         }
 
@@ -622,23 +620,25 @@ static int analyze_file (char *infilename, uint32_t *histogram, float *peak)
                 display_progress (progress);
                 progress = floor (progress * 100.0 + 0.5);
 
-                if (!quiet_mode)
+                if (!quiet_mode) {
                     fprintf (stderr, "%s%3d%% done...",
                         nobs ? " " : "\b\b\b\b\b\b\b\b\b\b\b\b", (int) progress);
+                    fflush (stderr);
+                }
         }
     }
 
     free (temp_buffer);
 
-    if (result == NO_ERROR && WavpackGetNumSamples (wpc) != (uint32_t) -1 &&
+    if (result == WAVPACK_NO_ERROR && WavpackGetNumSamples (wpc) != (uint32_t) -1 &&
         total_unpacked_samples != WavpackGetNumSamples (wpc)) {
             error_line ("incorrect number of samples!");
-            result = SOFT_ERROR;
+            result = WAVPACK_SOFT_ERROR;
     }
 
-    if (result == NO_ERROR && WavpackGetNumErrors (wpc)) {
+    if (result == WAVPACK_NO_ERROR && WavpackGetNumErrors (wpc)) {
         error_line ("crc errors detected in %d block(s)!", WavpackGetNumErrors (wpc));
-        result = SOFT_ERROR;
+        result = WAVPACK_SOFT_ERROR;
     }
 
     WavpackCloseFile (wpc);
@@ -660,7 +660,7 @@ static int update_file (char *infilename, float track_gain, float track_peak, fl
 
     if (!wpc) {
         error_line (error);
-        return SOFT_ERROR;
+        return WAVPACK_SOFT_ERROR;
     }
 
     if (clean_mode) {
@@ -740,11 +740,11 @@ static int update_file (char *infilename, float track_gain, float track_peak, fl
 
     if (write_tag && !WavpackWriteTag (wpc)) {
         error_line ("%s", WavpackGetErrorMessage (wpc));
-        return SOFT_ERROR;
+        return WAVPACK_SOFT_ERROR;
     }
 
     WavpackCloseFile (wpc);
-    return NO_ERROR;
+    return WAVPACK_NO_ERROR;
 }
 
 // Just show any ReplayGain tags for the specified file
@@ -761,7 +761,7 @@ static int show_file_info (char *infilename, FILE *dst)
 
     if (!wpc) {
         error_line (error);
-        return SOFT_ERROR;
+        return WAVPACK_SOFT_ERROR;
     }
 
     fprintf (dst, "\nfile: %s\n", infilename);
@@ -790,7 +790,7 @@ static int show_file_info (char *infilename, FILE *dst)
         fprintf (dst, "no ReplayGain values found\n");
 
     WavpackCloseFile (wpc);
-    return NO_ERROR;
+    return WAVPACK_NO_ERROR;
 }
 
 // Calculate the ReplayGain value from the specified loudness histogram; clip to -24 / +64 dB
