@@ -31,11 +31,11 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 
-#if defined (WIN32) || defined (__OS2__)
+#if defined (_WIN32) || defined (__OS2__)
 #include <io.h>
 #endif
 
-#ifdef WIN32
+#ifdef _WIN32
 #define fileno _fileno
 #endif
 
@@ -130,7 +130,7 @@ WavpackContext *WavpackOpenFileInput (const char *infilename, char *error, int f
 
     if (*infilename == '-') {
         wv_id = stdin;
-#if defined(WIN32)
+#if defined(_WIN32)
         _setmode (fileno (stdin), O_BINARY);
 #endif
 #if defined(__OS2__)
